@@ -10,5 +10,5 @@ class GraphManager:
         CreateTrainAndSaveGCN(traindata, testdata,save_dataset_fd, nb_classes)
         print("===== Modèle entrainé et sauvegardé =====")
 
-    def single_prediction(self, saved_model_folder,document_to_predict_json, labels_tab):
-        return predictionsUnique(saved_model_folder,document_to_predict_json, labels_tab)
+    def single_prediction(self, saved_model_folder, saved_prediction_dataset_folder, document_to_predict_json, labels_tab):
+        return predictionsUnique(saved_model_folder, saved_prediction_dataset_folder, document_to_predict_json, labels_tab)
